# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_bigquery_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_bigquery_pb2 as gcp_dot_gcp__bigquery__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$gcp/gcp_google_bigquery_bundle.proto\x12&oak9.tython.gcp.google_bigquery_bundle\x1a\x13shared/shared.proto\x1a\x16gcp/gcp_bigquery.proto\"\xbb\x06\n\x0eGoogleBigquery\x12\x43\n\x10\x62igquery_dataset\x18\x01 \x01(\x0b\x32).oak9.tython.gcp.bigquery.BigqueryDataset\x12P\n\x17\x62igquery_dataset_access\x18\x02 \x03(\x0b\x32/.oak9.tython.gcp.bigquery.BigqueryDatasetAccess\x12Y\n\x1c\x62igquery_dataset_iam_binding\x18\x03 \x03(\x0b\x32\x33.oak9.tython.gcp.bigquery.BigqueryDatasetIamBinding\x12W\n\x1b\x62igquery_dataset_iam_member\x18\x04 \x03(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryDatasetIamMember\x12W\n\x1b\x62igquery_dataset_iam_policy\x18\x05 \x03(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryDatasetIamPolicy\x12\x43\n\x10\x62igquery_routine\x18\x06 \x03(\x0b\x32).oak9.tython.gcp.bigquery.BigqueryRoutine\x12?\n\x0e\x62igquery_table\x18\x07 \x03(\x0b\x32\'.oak9.tython.gcp.bigquery.BigqueryTable\x12U\n\x1a\x62igquery_table_iam_binding\x18\x08 \x03(\x0b\x32\x31.oak9.tython.gcp.bigquery.BigqueryTableIamBinding\x12S\n\x19\x62igquery_table_iam_member\x18\t \x03(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryTableIamMember\x12S\n\x19\x62igquery_table_iam_policy\x18\n \x03(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryTableIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_bigquery_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEBIGQUERY._serialized_start=126
  _GOOGLEBIGQUERY._serialized_end=953
# @@protoc_insertion_point(module_scope)
