"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_bigquery_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleBigquery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIGQUERY_DATASET_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_ACCESS_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_BINDING_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_MEMBER_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_POLICY_FIELD_NUMBER: builtins.int
    BIGQUERY_ROUTINE_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_BINDING_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def bigquery_dataset(self) -> gcp.gcp_bigquery_pb2.BigqueryDataset: ...
    @property
    def bigquery_dataset_access(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetAccess]: ...
    @property
    def bigquery_dataset_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamBinding]: ...
    @property
    def bigquery_dataset_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamMember]: ...
    @property
    def bigquery_dataset_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamPolicy]: ...
    @property
    def bigquery_routine(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryRoutine]: ...
    @property
    def bigquery_table(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTable]: ...
    @property
    def bigquery_table_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamBinding]: ...
    @property
    def bigquery_table_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamMember]: ...
    @property
    def bigquery_table_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamPolicy]: ...
    def __init__(
        self,
        *,
        bigquery_dataset: gcp.gcp_bigquery_pb2.BigqueryDataset | None = ...,
        bigquery_dataset_access: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetAccess] | None = ...,
        bigquery_dataset_iam_binding: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamBinding] | None = ...,
        bigquery_dataset_iam_member: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamMember] | None = ...,
        bigquery_dataset_iam_policy: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamPolicy] | None = ...,
        bigquery_routine: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryRoutine] | None = ...,
        bigquery_table: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTable] | None = ...,
        bigquery_table_iam_binding: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamBinding] | None = ...,
        bigquery_table_iam_member: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamMember] | None = ...,
        bigquery_table_iam_policy: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_dataset", b"bigquery_dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_dataset", b"bigquery_dataset", "bigquery_dataset_access", b"bigquery_dataset_access", "bigquery_dataset_iam_binding", b"bigquery_dataset_iam_binding", "bigquery_dataset_iam_member", b"bigquery_dataset_iam_member", "bigquery_dataset_iam_policy", b"bigquery_dataset_iam_policy", "bigquery_routine", b"bigquery_routine", "bigquery_table", b"bigquery_table", "bigquery_table_iam_binding", b"bigquery_table_iam_binding", "bigquery_table_iam_member", b"bigquery_table_iam_member", "bigquery_table_iam_policy", b"bigquery_table_iam_policy"]) -> None: ...

global___GoogleBigquery = GoogleBigquery
